parse_rapx_attr

Function parse_rapx_attr 

pub fn parse_rapx_attr(
    attr_str: &str,
    expected_name: &str,
) -> Result<ParsedRapxAttr>
Parse a raw attribute string into a structured requires representation.

Returns an empty default value when the attribute does not match rapx::requires or when it is not a list attribute.